==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Farchive_mail.0.7-1.4.0.tar.gz: archive_mail/includes/formats/seperate.php <==
<?php
/*******************************************************************************

    Author ......... Jimmy Conner
    Contact ........ jimmy@advcs.org
    Home Site ...... http://www.advcs.org/
    Program ........ Archive Mail
    Version ........ 0.7
    Purpose ........ Allows you to download your email in a compressed archive

*******************************************************************************/

               $message2 = sqimap_get_message($imapConnection, $id, $mailbox);
               $count = count($message2->entities);
               if ($count == 0)
                  $count = 1;
               $k = $i + $start_index;
               $seen = $msgs[$k]['FLAG_SEEN'];
               $date = decodeHeader($message2->rfc822_header->date);
               $date = date('m-j-y', $date);
               $email2 = $msgs[$k]['FROM'][0][0];
               $subject2 = $msgs[$k]['SUBJECT'];
//               $email2 = decodeHeader($message2->rfc822_header->getAddr_s('from'));
               $email = archive_replace_str($email2);
//               $subject2 = decodeHeader($message2->rfc822_header->subject);
               $subject = archive_replace_str($subject2);
               if ($subject == '')
                  $subject = 'No Subject';
               $to = decodeHeader($message2->rfc822_header->getAddr_s('to'));
               for ($b = 1; $b < $count + 1; $b++) {
                  $filename = '';
                  $message = $message2->getEntity($b);
                  $header = $message->rfc822_header;
                  $body = mime_fetch_body ($imapConnection, $id, $b);
                  $body = decodeBody($body, $message->header->encoding);
                  $filename = $message->header->getParameter('filename');
                  if (!$filename)
                     $filename = $message->header->getParameter('name');
                  $type0 = $message->type0;
                  $type1 = $message->type1;
                  if (isset($override_type0))
                     $type0 = $override_type0;
                  if (isset($override_type1))
                     $type1 = $override_type1;
                  if (($filename  || ($type1 == 'rfc822' && $type0 == 'message')) && $archiveattachments == 0) {
                     // We don't want to download attachments
                  }else{
                     $suffix = '';
                     $isattachment = false;
                     $filename = archive_replace_str($filename);
                     if ($filename)
                     $isattachment = true;
                     if (strlen($filename) < 1) {
                        if ($type1 == 'plain' && $type0 == 'text') {
                           $suffix = '.txt';
                        } else if ($type1 == 'richtext' && $type0 == 'text') {
                           $suffix = '.rtf';
                        } else if ($type1 == 'postscript' && $type0 == 'application') {
                           $suffix = '.ps';
                        } else if ($type1 == 'rfc822' && $type0 == 'message') {
                           $suffix = '.eml';
                        } else {
                           if ($type1 != '')
                              $suffix = ".$type1";
                           else
                              $suffix = '';
                        }
                        if ($filename == '') {
                           if ($archivefilenames < 1)
                              $archivefilenames = 0;
                        }
                        $name = archive_names ($archivefilenames, $email, $date, $c, $subject);
                        $increment = checkincrement($name . $suffix);
                        $filename = $name . $increment;
                     }
                     $filename = $filename . $suffix;
                  $temp = '';
                  if (!$isattachment && ($type0 == 'text' || ($type0 == '' && $type1 == ''))) {
                     if ($type1 == 'plain' || $type1 == '') {
                        $temp = _("Subject") . ": $subject2\r\n" .
                        '   ' . _("From") . ": $email2\r\n" .
                        '     ' . _("To") . ": $to\r\n" .
                        '   ' . _("Date") . ": $date\r\n\r\n";
                     } elseif ($type1 == 'html') {
                        $temp = "<table><tr><th align=right>" . _("Subject").
                            ":</th><td>$subject2" .
                            "</td></tr>\r\n<tr><th align=right>" . _("From").
                            ":</th><td>$email2" .
                            "</td></tr>\r\n<tr><th align=right>" . _("To").
                            ":</th><td>$to" .
                            "</td></tr>\r\n<tr><th align=right>" . _("Date").
                            ":</th><td>$date" .
                            "</td></tr>\r\n</table>\n<hr>\r\n";
                     }
                  }
                  $body = $temp . $body;
                  $zipfile -> addFile($body, $filename);
               }
               if (!$seen)
                  sqimap_toggle_flag($imapConnection, $id, '\\Seen',false,true);
            }
?>

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Farchive_mail.0.8-1.4.2.tar.gz: archive_mail/includes/formats/seperate.php <==
<?php
/*******************************************************************************

    Author ......... Jimmy Conner
    Contact ........ jimmy@advcs.org
    Home Site ...... http://www.advcs.org/
    Program ........ Archive Mail
    Version ........ 0.8
    Purpose ........ Allows you to download your email in a compressed archive

*******************************************************************************/

               $message2 = sqimap_get_message($imapConnection, $id, $mailbox);
               $count = count($message2->entities);
               if ($count == 0)
                  $count = 1;
               $k = $i + $start_index;
               $seen = $msgs[$k]['FLAG_SEEN'];
               $date = decodeHeader($message2->rfc822_header->date);
               $date = date('m-j-y', $date);
               $email2 = $msgs[$k]['FROM'];
               if (strpos($email2, '<') !== false)
                  $email2 = substr($email2, strpos($email2, '<')+1, strlen($email2) - strpos($email2, '<')-2);
               $subject2 = $msgs[$k]['SUBJECT'];
//               $email2 = decodeHeader($message2->rfc822_header->getAddr_s('from'));
               $email = archive_replace_str($email2);
//               $subject2 = decodeHeader($message2->rfc822_header->subject);
               $subject = archive_replace_str($subject2);
               if ($subject == '')
                  $subject = 'No Subject';
               $to = decodeHeader($message2->rfc822_header->getAddr_s('to'));
               for ($b = 1; $b < $count + 1; $b++) {
                  $filename = '';
                  $message = $message2->getEntity($b);
                  $header = $message->rfc822_header;
                  $body = mime_fetch_body ($imapConnection, $id, $b);
                  $body = decodeBody($body, $message->header->encoding);
                  $filename = $message->header->getParameter('filename');
                  if (!$filename)
                     $filename = $message->header->getParameter('name');
                  $type0 = $message->type0;
                  $type1 = $message->type1;
                  if (isset($override_type0))
                     $type0 = $override_type0;
                  if (isset($override_type1))
                     $type1 = $override_type1;
                  if (($filename  || ($type1 == 'rfc822' && $type0 == 'message')) && $archiveattachments == 0) {
                     // We don't want to download attachments
                  }else{
                     $suffix = '';
                     $isattachment = false;
                     $filename = archive_replace_str($filename);
                     if ($filename)
                     $isattachment = true;
                     if (strlen($filename) < 1) {
                        if ($type1 == 'plain' && $type0 == 'text') {
                           $suffix = '.txt';
                        } else if ($type1 == 'richtext' && $type0 == 'text') {
                           $suffix = '.rtf';
                        } else if ($type1 == 'postscript' && $type0 == 'application') {
                           $suffix = '.ps';
                        } else if ($type1 == 'rfc822' && $type0 == 'message') {
                           $suffix = '.eml';
                        } else {
                           if ($type1 != '')
                              $suffix = ".$type1";
                           else
                              $suffix = '';
                        }
                        if ($filename == '') {
                           if ($archivefilenames < 1)
                              $archivefilenames = 0;
                        }
                        $name = archive_names ($archivefilenames, $email, $date, $c, $subject);
                        $increment = checkincrement($name . $suffix);
                        $filename = $name . $increment;
                     }
                     $filename = $filename . $suffix;
                  $temp = '';
                  if (!$isattachment && ($type0 == 'text' || ($type0 == '' && $type1 == ''))) {
                     if ($type1 == 'plain' || $type1 == '') {
                        $temp = _("Subject") . ": $subject2\r\n" .
                        '   ' . _("From") . ": $email2\r\n" .
                        '     ' . _("To") . ": $to\r\n" .
                        '   ' . _("Date") . ": $date\r\n\r\n";
                     } elseif ($type1 == 'html') {
                        $temp = "<table><tr><th align=right>" . _("Subject").
                            ":</th><td>$subject2" .
                            "</td></tr>\r\n<tr><th align=right>" . _("From").
                            ":</th><td>$email2" .
                            "</td></tr>\r\n<tr><th align=right>" . _("To").
                            ":</th><td>$to" .
                            "</td></tr>\r\n<tr><th align=right>" . _("Date").
                            ":</th><td>$date" .
                            "</td></tr>\r\n</table>\n<hr>\r\n";
                     }
                  }
                  $body = $temp . $body;
                  $zipfile -> addFile($body, $filename);
               }
               if (!$seen)
                  sqimap_toggle_flag($imapConnection, $id, '\\Seen',false,true);
            }
?>
